eta: Ideal Response Patterns for all possible attribute profiles
Description
This function is used to calculate ideal response patterns for all possible attribute profiles based on the DINA model (Junker & Sijtsma, 2001) or conjunctive-type cognitive diagnostic models.
Usage
eta(K, J, Q)
Value
A \(2^K \times J\) binary matrix will be returned. Each row of ideal response patterns is corresponding to each of the \(2^K\) possible attribute patterns, which can be obtained from alpha.
Arguments
K
The number of attributes.
J
The number of items.
Q
A required \(J \times K\) binary item-by-attribute association matrix (Q-matrix), where \(K\) is the number of attributes. The \(j^{th}\) row of the matrix is an indicator vector, 1 indicating attributes are required and 0 indicating attributes are not required to master item \(j\).
References
Junker, B., & Sijtsma, K. (2001). Cognitive Assessment Models with Few Assumptions, and Connections with Nonparametric Item Response Theory. Applied Psychological Measurement, 25(3), 258-272.